@@ -337,7 +337,7 @@ def build2(javaEnv, dirs, buildApi="True", buildWorker="True"):
 	local("pwd")
 	local('mvn clean install -DskipTests')
 
-	if buildApi:
+	if buildApi in TRUTH_VALUES:
 	    local('mkdir -p deploy/api/config')
 	    local('mkdir -p deploy/api/lib')
 	 
@@ -350,7 +350,7 @@ def build2(javaEnv, dirs, buildApi="True", buildWorker="True"):
 	    local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
 
-	if buildWorker:
+	if buildWorker in TRUTH_VALUES:
 	    local('mkdir -p deploy/worker/config')
 	    local('mkdir -p deploy/worker/lib')
 
